#
# spec file for package ghc-tagsoup
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name tagsoup
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.14.7
Release:        1.2
Summary:        Parsing and extracting information from (possibly malformed) HTML/XML documents
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-time-devel
%endif

%description
TagSoup is a library for parsing HTML/XML. It supports the HTML 5
specification, and can be used to parse either well-formed XML, or unstructured
and malformed HTML from the web. The library also provides useful functions to
extract information from an HTML document, making it ideal for screen-scraping.

Users should start from the "Text.HTML.TagSoup" module.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.txt README.md

%changelog
* Wed Oct 10 2018 psimons@suse.com
- Update tagsoup to version 0.14.7.
  0.14.7, released 2018-09-18
    [#75], escape single quote (') characters as &#39;
    [#72], update some dead URLs
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update tagsoup to version 0.14.6.
  * Fix up source positions on bogus <! markers
  * Fix up source positions on bogus <? markers
  * #71, fix up source positions on bogus comments
  * #70, fix up source positions on comments
  * #66, make sure positions are correct for lone & characters
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 0.14.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.14 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.13.10 revision 0 with cabal2obs.
* Sat May  7 2016 mimi.vx@gmail.com
- update to 0.13.10
  * improve the Haddock documentation
  * fix some > 16bit HTML entities
* Wed Mar 16 2016 mimi.vx@gmail.com
- update to 0.13.9
  * fix a space leak
  * fix the demo examples
  * make IsString a superclass of StringLike
  * make flattenTree O(n) instead of O(n^2)
* Mon Jan 11 2016 mimi.vx@gmail.com
- update to 0.13.8
  * add parse/render functions directly to the Tree module
* Sun Jan 10 2016 mimi.vx@gmail.com
- update to 0.13.7
  * make sure upper case &#X works in lookupEntity
* Thu Dec 24 2015 mimi.vx@gmail.com
- update to 0.13.6
  * some named entities require a trailing semicolon (e.g. mid)
* Wed Nov  4 2015 mimi.vx@gmail.com
- update to 0.13.5
  * add isTagComment function
* Thu Apr 23 2015 mimi.vx@gmail.com
- update to 0.13.3
  * #562, treat <script> specially as per HTML5
  * #616, extend to all HTML5 entities
  * Optimise lookupNamedEntity
  * Replace escapeXMLChar with escapeXML
  * Change all Entity functions to return String, not Int or Char
* Mon Oct 21 2013 sbahling@suse.com
- spec file: Add %%defattr(-,root,root,-) to %%files devel section
* Tue May 14 2013 peter.trommler@ohm-hochschule.de
- new cabal-rpm spec file template
  * no macros spanning multiple spec file sections
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.12.8 from upstream (no changelog)
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 spec file template
* Fri Jan 20 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
